@@ -1,26 +1,31 @@
-/* $Id: textwidget.cc 613 2006-05-10 20:59:28Z murrayc $ */
+/* $Id$ */
 
 /* textwidget.cc
  *
  * Copyright (C) 2001-2002 The gtkmm Development Team
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#include <cstring>
 #include "textwidget.h"
 #include "pangomm/fontdescription.h"
+  
+using std::strstr;
+using std::strncmp;
+using std::strlen;
 
 
 TextWidget::TextWidget(bool is_source)
